<?php

namespace EventPortal\Domain\Permission\Models;

use EventPortal\Domain\Component\Option;
use Illuminate\Database\Eloquent\Builder;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;
use Spatie\Permission\Models\Role as RoleModel;

class Role extends RoleModel implements AuditableInterface
{
    const KEY = 'role';

    use Auditable;

    public static function allAsOptions(): array
    {
        return Role::query()
            ->orderBy('label', 'asc')
            ->get()
            ->map(function (Role $role) {
                return Option::make($role->label)->value($role->id);
            })
            ->toArray();
    }

    public function scopeWithoutSuperAdmin(Builder $query): Builder
    {
        return $query->where('name', '!=', 'super-admin');
    }
}
