<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class TransitionEventTest extends TestCase
{
    use RefreshDatabase, SeedRolesAndPermissions;

    /** @test */
    public function change_status_from_draft_to_published()
    {
        $event = factory(Event::class)->state('draft')->create();

        $this->actingAsSuperAdmin()
            ->post(route('admin.event.transition', [
                'event' => $event,
                'type' => 'publish',
            ]));

        $this->assertEquals('published', $event->fresh()->status);
    }

    /** @test */
    public function cannot_go_from_draft_to_cancelled()
    {
        $event = factory(Event::class)->state('draft')->create();

        $this->actingAsSuperAdmin()
            ->post(route('admin.event.transition', [
                'event' => $event,
                'type' => 'cancel',
            ]));

        $this->assertEquals('draft', $event->fresh()->status);
    }

    /** @test **/
    public function cannot_change_event_status_without_edit_permission()
    {
        $event = factory(Event::class)->state('draft')->create();
        $admin = factory(Admin::class)->state('admin')->create();

        $permission = factory(Permission::class)->create([
            'name' => 'event.update',
        ]);

        $admin->givePermissionTo($permission);

        $this->actingAsAdmin($admin)
            ->post(route('admin.event.transition', [
                'event' => $event,
                'type' => 'publish',
            ]))
            ->assertUnauthorized();

        $this->assertEquals('draft', $event->fresh()->status);
    }
}
